#include "thumbclass.h"
#include <stdio.h>

ImageWindow::ImageWindow(BRect frame, const char *title, window_type type,
			uint32 flags, uint32 workspaces, ImagingView *aview)
	: BWindow(frame, title, type, flags, workspaces)
{
	view = aview; // copy pointer so as to allow deallocation later
}

void
ImageWindow::Quit(void)
{
	printf("\ninside ImageWindow::Quit()\n");
	RemoveChild(view);
	view->KillViews();
	view->~ImagingView();
	delete view;
	BWindow::Quit();
}

//---------------------------------------------------//
// end of ImageWindow Class //
// start of ImagingView Class //
//---------------------------------------------------//

ImagingView::ImagingView(BRect frame, const char *name, uint32 resizingMode, uint32 flags, BBitmap *imgbmp, BEntry entry, bool thumb)
	: BView(frame, name, resizingMode, flags)
{

	img_entry = entry;
	SetViewColor(B_TRANSPARENT_32_BIT);
	fSourceImage = imgbmp;
	first_draw = true;
	thumbnail = thumb;
}


void
ImagingView::AttachedToWindow()
{
	// Now create the main offscreen image and view and draw the
	// unaltered source into it.
	fOffscreenView = new BView(fSourceImage->Bounds(), "offscreen", B_FOLLOW_NONE, B_WILL_DRAW /*| B_FULL_UPDATE_ON_RESIZE*/);
	fOffscreenImage = new BBitmap(fSourceImage->Bounds(),B_RGB32_BIG, TRUE);
	fOffscreenImage->Lock();
	fOffscreenImage->AddChild(fOffscreenView);
	fOffscreenView->DrawBitmap(fSourceImage);
	fOffscreenView->Sync();
	fOffscreenView->RemoveSelf();
	fOffscreenImage->Unlock();
	delete	fOffscreenView;
}

void
ImagingView::FrameResized(float width, float height)
{
	if(thumbnail != true) {
		DrawBitmap(fOffscreenImage, Bounds());
	}
}


ImagingView
*ImagingView::PreviousSibling(void)
{
	printf("\nprevious sibling code called\n");
	return (ImagingView *) BView::PreviousSibling();
}


void
ImagingView::MouseDown(BPoint point)
{
	BMessage 	mymsg;
	BPath		mypath;

	if (thumbnail == true) {
		// send a message to be_app
		img_entry.GetPath(&mypath);	
		printf("\nselected => %s\n", mypath.Path());
		mymsg.what = 'ENTR';
		mymsg.AddString("img_path", mypath.Path());
		be_app->PostMessage(&mymsg);
	}
}

void
ImagingView::Draw(BRect updateRect)
{
	if (first_draw == true) {
		first_draw = false;
	}
	DrawBitmap(fOffscreenImage, Bounds());
}


bool
ImagingView::KillViews(void)
{
	printf("\nImagingView::KillViews()\n");
	fOffscreenImage->~BBitmap();
	delete	fOffscreenImage;
	return true;
}

//------------------------------------------------------//
//------------------------------------------------------//
//------------ End of Imaging View ---------------------//
//--------- Beginning of ImageWindow -------------------//
//------------------------------------------------------//
//------------------------------------------------------//

